@@ -5,7 +5,7 @@ import numpy as np
 import numpy.typing as npt
 import tensorflow as tf  # type: ignore
 
-from code_loader.contract.visualizer_classes import  LeapImage, LeapText, LeapNumeric, LeapGraph, LeapHorizontalBar, \
+from code_loader.contract.visualizer_classes import  LeapImage, LeapText, LeapGraph, LeapHorizontalBar, \
     LeapTextMask, LeapImageMask
 from code_loader.contract.enums import DataStateType, DatasetMetadataType, \
     DataStateEnum, LeapDataType, Metric
@@ -32,14 +32,9 @@ class PreprocessHandler:
     function: Callable[[], List[PreprocessResponse]]
     data_length: Dict[DataStateType, int] = field(default_factory=dict)
 
-@dataclass
-class UnlabeledDataPreprocessHandler:
-    function: Callable[[], PreprocessResponse]
-    data_length: int = 0
 
 VisualizerCallableInterface = Union[
     Callable[..., LeapImage],
-    Callable[..., LeapNumeric],
     Callable[..., LeapText],
     Callable[..., LeapGraph],
     Callable[..., LeapHorizontalBar],
@@ -47,7 +42,7 @@ VisualizerCallableInterface = Union[
     Callable[..., LeapTextMask],
 ]
 
-VisualizerCallableReturnType = Union[LeapImage, LeapNumeric, LeapText,
+VisualizerCallableReturnType = Union[LeapImage, LeapText,
                                      LeapGraph, LeapHorizontalBar, LeapImageMask, LeapTextMask]
 
 CustomCallableInterface = Callable[[tf.Tensor, tf.Tensor], tf.Tensor]
@@ -102,7 +97,6 @@ class PredictionTypeHandler:
 @dataclass
 class DatasetIntegrationSetup:
     preprocess: Optional[PreprocessHandler] = None
-    unlabeled_data_preprocess: Optional[UnlabeledDataPreprocessHandler] = None
     visualizers: List[VisualizerHandler] = field(default_factory=list)
     inputs: List[InputHandler] = field(default_factory=list)
     ground_truths: List[GroundTruthHandler] = field(default_factory=list)
@@ -114,7 +108,7 @@ class DatasetIntegrationSetup:
 @dataclass
 class DatasetSample:
     inputs: Dict[str, npt.NDArray[np.float32]]
-    gt: Optional[Dict[str, npt.NDArray[np.float32]]]
+    gt: Dict[str, npt.NDArray[np.float32]]
     metadata: Dict[str, Union[str, int, bool, float]]
     index: int
     state: DataStateEnum
