@@ -6,8 +6,7 @@ class Metric(Enum):
     MeanSquaredLogarithmicError = 'MeanSquaredLogarithmicError'
     MeanAbsoluteError = 'MeanAbsoluteError'
     MeanAbsolutePercentageError = 'MeanAbsolutePercentageError'
-    CategoricalAccuracy = 'CategoricalAccuracy'
-    MaskCategoricalAccuracy = 'MaskCategoricalAccuracy'
+    Accuracy = 'Accuracy'
     BinaryAccuracy = 'BinaryAccuracy'
     MeanIOU = 'MeanIOU'
 
@@ -16,7 +15,6 @@ class LeapDataType(Enum):
     Image = 'Image'
     Text = 'Text'
     Graph = 'Graph'
-    Numeric = 'Numeric'
     HorizontalBar = 'HorizontalBar'
     ImageMask = 'ImageMask'
     TextMask = 'TextMask'
